" Vim filetype plugin file
" Language:        OpenSSH server configuration file
" Maintainer:      Yinzuo Jiang <jiangyinzuo@foxmail.com>
" Latest Revision: 2024-05-17

if exists("b:did_ftplugin")
  finish
endif

runtime! ftplugin/conf.vim
